@@ -287,15 +287,22 @@ def update(config, tag=""):
         to_state = "0preinstall" if to_state == "install" else to_state
         setup_dict = config["param_dict"].copy()
         setup_dict["unset_mode"] = "fi"
+        setup_str = vm_params.get("remove_set", "leaves")
+        for restriction in config["available_restrictions"]:
+            if restriction in setup_str:
+                break
+        else:
+            setup_str = "all.." + setup_str
+        setup_str = param.re_str(setup_str)
         # remove all test nodes depending on the updated node if present (unset mode is "ignore otherwise")
         remove_graph = l.parse_object_trees(setup_dict,
-                                            param.re_str(vm_params.get("remove_set", "leaves")),
+                                            setup_str,
                                             config["available_vms"],
                                             prefix=tag, verbose=False)
         remove_graph.flag_children(flag_type="run", flag=False)
         remove_graph.flag_children(flag_type="clean", flag=False)
         remove_graph.flag_children(to_state, vm_name, flag_type="clean", flag=True, skip_roots=True)
-        r.run_traversal(remove_graph, config["param_dict"])
+        r.run_traversal(remove_graph, {"vms": vm_name, **config["param_dict"]})
 
         logging.info("Updating all states before '%s'", to_state)
         setup_dict = config["param_dict"].copy()
@@ -322,6 +329,7 @@ def update(config, tag=""):
         # states are not removed, aborting in any other case
         setup_dict = config["param_dict"].copy()
         setup_dict.update({"get_mode": "ra", "set_mode": "fa", "unset_mode": "ra"})
+        setup_dict["vms"] = vm_name
         r.run_traversal(update_graph, setup_dict)
 
     LOG_UI.info("Finished update setup")
@@ -340,13 +348,14 @@ def run(config, tag=""):
     # NOTE: each run expects already incremented count in the beginning but this prefix
     # is preferential to setup chains with a single "run" step since this is usually the case
     config["prefix"] = tag + "n" if len(re.findall("run", config["vms_params"]["setup"])) > 1 else ""
-    config["test_runner"] = "traverser"
+    config["run.test_runner"] = "traverser"
 
-    config["sysinfo"] = config.get("sysinfo", "on")
-    config["html_job_result"] = config.get("html_job_result", "on")
-    config["json_job_result"] = config.get("json_job_result", "on")
-    config["xunit_job_result"] = config.get("xunit_job_result", "on")
-    config["tap_job_result"] = config.get("tap_job_result", "on")
+    config["sysinfo.collect.enabled"] = config.get("sysinfo.collect.enabled", "on")
+    config["run.html.job_result"] = config.get("run.html.job_result", "on")
+    config["run.json.job_result"] = config.get("run.json.job_result", "on")
+    config["run.xunit.job_result"] = config.get("run.xunit.job_result", "on")
+    config["run.tap.job_result"] = config.get("run.tap.job_result", "on")
+    config["run.journal.enabled"] = config.get("run.journal.enabled", "on")
 
     # essentially we imitate the auto plugin to make the tool plugin a superset
     with new_job(config) as job:
