@@ -174,8 +174,6 @@ class CartesianRunner(TestRunner):
 
         graph = self._graph_from_suite(test_suite)
         summary = set()
-        if self.job.sysinfo is not None:
-            self.job.sysinfo.start_job_hook()
         params = self.job.config["param_dict"]
 
         try:
@@ -185,8 +183,6 @@ class CartesianRunner(TestRunner):
             TEST_LOG.error('Job interrupted by ctrl+c.')
             summary.add('INTERRUPTED')
 
-        if self.job.sysinfo is not None:
-            self.job.sysinfo.end_job_hook()
         self.result.end_tests()
         self.job.funcatexit.run()
         signal.signal(signal.SIGTSTP, signal.SIG_IGN)
@@ -324,9 +320,10 @@ class CartesianRunner(TestRunner):
                 object_name = test_object.name
                 object_params = test_node.params.object_params(object_name)
                 # if previous state is not known keep behavior assuming that the user knows what they are doing
-                if object_params.get("set_state") != test_object.current_state != "unknown":
-                    logging.debug("Re-running ephemeral setup %s since %s state was switched to %s",
-                                  test_node.params["shortname"], test_object.name, test_object.current_state)
+                required_state = object_params.get("set_state")
+                if required_state != test_object.current_state != "unknown":
+                    logging.debug("Re-running ephemeral setup %s since %s state was switched to %s but test requires %s",
+                                  test_node.params["shortname"], test_object.name, test_object.current_state, required_state)
                     test_node.should_run = True
                     break
         if test_node.should_run:
@@ -357,8 +354,10 @@ class CartesianRunner(TestRunner):
             for test_object in test_node.objects:
                 object_name = test_object.name
                 object_params = test_node.params.object_params(object_name)
-                if object_params.get("set_state") is not None and object_params.get("set_state") != "":
-                    test_object.current_state = object_params.get("set_state")
+                # if a state was set it is final and the retrieved state was overwritten
+                object_state = object_params.get("set_state", object_params.get("get_state"))
+                if object_state is not None and object_state != "":
+                    test_object.current_state = object_state
             test_node.should_run = False
         else:
             logging.debug("Skipping test %s", test_node.params["shortname"])
@@ -378,7 +377,10 @@ class CartesianRunner(TestRunner):
             else:
                 for vm_name in test_node.params.objects("vms"):
                     vm_params = test_node.params.object_params(vm_name)
-                    # avoid running any test unless the user really requires cleanup
+                    # avoid running any test for unselected vms
+                    if vm_name not in params.get("vms", param.all_vms()):
+                        continue
+                    # avoid running any test unless the user really requires cleanup and such is needed
                     if vm_params.get("unset_mode", "ri")[0] == "f" and vm_params.get("set_state"):
 
                         setup_dict = {} if params is None else params.copy()
